# Easyreport


Link to [PyPI](https://pypi.org/project/easyreport/)


## Installation

Run the following to install:

```python
pip install easyreport
```

## Usage

```python
import report

# get classification_report
report.classification_report(df_features,df_target,test_size=0.3)
```

## Future works
1. Optimization
2. Add more functionality

## Drawbacks
1. Not suitable for large datasets
2. Limited to existing users only
